# Data analysis script for Stroop Experiment 1 RT instrument identification
# April 2018
# by Zachary Wallmark

# Load libraries
set.seed(1234)

library(readr)
library(readxl)
library(tidyverse)
library(gmodels)
library(plotrix)
library(lmer4)
library(car)

## Load data
id = readRDS(file = "ex1.rds")

################################
## OUTLIER REMOVAL
################################
# Subject accuracy (to check for outliers):
accuracy_outliers <- id %>% 
  group_by(Subj) %>%
  summarise(err = 1 - mean(Accuracy)) %>%
  arrange(desc(err))
print(accuracy_outliers) # nobody with performance worse than chance

# make outlier trim files for comparative use later: id_trim
id_outliers <- id %>% filter(RT > 2000 & RT < 100)
id_trim <- id %>% filter(RT < 2000 & RT > 100)

id_trim1 = id_trim %>% filter(Accuracy == "TRUE") # make outlier-trimmed, correct-only df: id_trim1

###########################
## DESCRIPTIVE ##
###########################
# Descriptive stats by Trial, Type, and Group. NOTE: only correct responses, prefiltered for outliers (above)
describe_filter <- id_trim %>% 
  group_by(Task, Congruency) %>% 
  summarise(med = median(RT), IQR = IQR(RT), error = 1 - mean(Accuracy))
print(describe_filter)

# Describe overall
describe_overall <- id_trim %>% 
  group_by(Congruency) %>% 
  summarise(med = median(RT), IQR = IQR(RT), error = 1 - mean(Accuracy))
print(describe_overall)


################################
## ANALYSIS
################################
# RT mixed-effects model: control trimmed
id_trim1 = id_trim %>% filter(Congruency != "control")
id_mod = lmer(log ~ Task*Congruency*MT + (1|Subj), data = id_trim1)
summary(id_mod)
Anova(id_mod) # for Wald-chi^2

# check effect sizes of models
# R^2
r2.corr.mer <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$r.squared
}

#P-value
r2.corr.p <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$coefficients
}

r2.corr.mer(id_mod)
r2.corr.p(id_mod)

# Post-hoc
t.test(id_trim1$log, id_trim1$Congruency, p.adjust.method = "fdr")


# Error: LMM with control trimmed
err_mod = lmer(Accuracy ~ Task*Congruency*MT + (1|Subj), family = "binomial", data = id_trim %>% filter(Congruency != "control"))
summary(err_mod)
Anova(err_mod) # for Wald-chi^2

# model fit
r2.corr.mer(err_mod)
r2.corr.p(err_mod)

pairwise.t.test(id_trim$Accuracy, id_trim$Congruency, p.adjust.method = "fdr")


##########################
## Visualizations
########################## 
# Exploratory histograms
base <- id_trim %>% 
  group_by(Task, Congruency, MT) %>%
  ggplot(aes(x = log, fill = MT)) +
  geom_histogram(binwidth = .05)
base + facet_wrap(~Task)
base + facet_wrap(~Congruency)

# Graph by Task (Fig. 1)
id_trim1$Congruency <- factor(id_trim1$Congruency, levels = c("congruent", "incongruent"))
id_trim1 %>%
  group_by(Task, Congruency) %>%
  summarise(avg = median(RT), dev = std.error(RT)) %>%
  ggplot(aes(x = Congruency, y = avg, color = Task, group = Task)) +
  theme_bw() +
  geom_point(size = 3) +
  geom_line(size = 1) +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 1) +
  scale_y_continuous("RT (ms)") +
  xlab("Congruency") +
  theme(panel.spacing = unit(1, "lines")) +
  theme(text = element_text(size = 15)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank()) +
  theme(aspect.ratio = 1.1)
# save to file
ggsave("FIG1_Ex1.eps", dpi = 800)
