# Data analysis script for Stroop Experiment 2a RT/error timbre adjective associations
# April 2018
# by Zachary Wallmark

# Load libraries
set.seed(1234)

library(readr)
library(tidyverse)
library(readxl)
library(lme4)
library(car)
library(plotrix)

# Load data
stroop = readRDS(file = "exp2a.rds")

################################
## DESCRIPTION
################################
# demographic summary
demographic = rbind(nm_MT, m_MT)
demographic = semi_join(demographic, stroop, by = "Subj")
mean(demographic$Age, na.rm = T) # M age
sd(demographic$Age, na.rm = T) # SD age
table(demographic$instr_lesson_years) # distribution of musical training
table(demographic$gender) # distribution of sex

# Subject accuracy check: no trims necessary
stroop %>% 
  group_by(Subj) %>%
  summarise(err = 1- mean(Accuracy)) %>%
  arrange(desc(err))

# make outlier trim files for comparative use later: 53 RTs were either below 100ms or above 2000ms
stroop_outliers <- stroop %>% filter(RT < 100 | RT > 2000)
stroop_trim <- stroop %>% filter(RT > 100 & RT < 2000)

# Descriptive stats by Trial, Type, and Group. NOTE: filter all RTs above 2000ms as cutoff threshold for correct response.
stroop_trim %>% 
  group_by(Block, Modality, congruency) %>% 
  summarise(med = median(RT), IQR = IQR(RT), error = 1 - mean(Accuracy))


################################
## ANALYSIS
################################

# RT LMM 
stroop_trim1 = stroop_trim %>% filter(Accuracy == "TRUE")
stroop_trim1$congruency = relevel(stroop_trim1$congruency, ref = "incongruent")

stroopRT_mod = lmer(log ~ Modality*congruency*MT*Block + (1|Subj), data = stroop_trim1)
summary(stroopRT_mod)
Anova(stroopRT_mod) # for Wald-chi^2

# check model fit
r2.corr.mer <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$r.squared
}
r2.corr.p <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$coefficients
}

r2.corr.mer(stroopRT_mod)
r2.corr.p(stroopRT_mod)

# post hoc
pairwise.t.test(stroop_trim1$log, stroop_trim1$congruency, p.adjust.method = "fdr")


###############  Error LMM
stroopErr_mod = lmer(Accuracy ~ Modality*congruency*MT*Block + (1|Subj), family = "binomial", data = stroop_trim)
summary(stroopErr_mod)
Anova(stroopErr_mod) # for Wald-chi^2

# Model fit
r2.corr.mer(stroopErr_mod)
r2.corr.p(stroopErr_mod)

# post hoc congruency tests
pairwise.t.test(stroop_trim$Accuracy, stroop_trim$congruency, p.adjust.method = "fdr")


############### 
#Figures 
###############

# Figure 2a: congruency * block
blocklab = c("natural", "synthesizer")
stroop_trim1 %>% 
  group_by(Block, congruency) %>% 
  summarise(avg = median(RT), dev = std.error(RT)) %>% 
  ggplot(aes(x = Block, y = avg, color = congruency, group = congruency)) +
  theme_bw() +
  geom_point(size = 3, position = position_dodge(width = 0.2)) +
  geom_line(size = 1, position = position_dodge(width = 0.2)) +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 1, position = position_dodge(width = 0.2)) +
  xlab("Block (stimuli type)") +
  ylab("RT (ms)") +
  scale_y_continuous(limits = c(500, 525)) +
  scale_x_discrete(labels = blocklab) +
  theme(legend.key=element_blank(),legend.background=element_blank()) +
  scale_color_discrete(name="Congruency") +
  theme(text = element_text(size = 15)) +
  theme(aspect.ratio = 1.1) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank())
ggsave("FIG2_cond_block_interaction.eps", dpi = 800)

# Fig 2b: congruency * MT
grouplab = c("musicians", "non-musicians")
stroop_trim1 %>% 
  filter(MT != "NA") %>%
  group_by(MT, congruency) %>% 
  summarise(avg = median(RT), dev = std.error(RT)) %>% 
  ggplot(aes(x = MT, y = avg, color = congruency, group = congruency)) +
  theme_bw() +
  geom_point(size = 3, position = position_dodge(width = 0.2)) +
  geom_line(size = 1, position = position_dodge(width = 0.2)) +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 1, position = position_dodge(width = 0.2)) +
  xlab("Training") +
  ylab("RT (ms)") +
  scale_y_continuous(limits = c(495, 535)) +
  scale_x_discrete(labels = grouplab) +
  theme(legend.key=element_blank(),legend.background=element_blank()) +
  scale_color_discrete(name="Congruency") +
  theme(text = element_text(size = 15)) +
  theme(aspect.ratio = 1.1)
ggsave("FIG2b_cond_group_interaction.eps", dpi = 800)

# Fig 2c: Block * MT
stroop_trim1 %>% 
  filter(MT != "NA") %>%
  group_by(MT, Block) %>% 
  summarise(avg = median(RT), dev = std.error(RT)) %>% 
  ggplot(aes(x = MT, y = avg, color = Block, group = Block)) +
  theme_bw() +
  geom_point(size = 3, position = position_dodge(width = 0.2)) +
  geom_line(size = 1, position = position_dodge(width = 0.2)) +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 1, position = position_dodge(width = 0.2)) +
  xlab("Training") +
  ylab("RT (ms)") +
  scale_y_continuous(limits = c(500, 530)) +
  scale_x_discrete(labels = grouplab) +
  theme(legend.key=element_blank(),legend.background=element_blank()) +
  theme(text = element_text(size = 15)) +
  theme(aspect.ratio = 1.1)
ggsave("FIG2c_MT_block__interaction.eps", dpi = 800)

# Error main effect
stroop_trim$congruency = factor(stroop_trim$congruency, levels = c("control", "congruent", "incongruent"))
err = stroop_trim %>% 
  group_by(congruency) %>% 
  summarise(avg = 1 - mean(Accuracy), dev = std.error(Accuracy)) %>% 
  ggplot(aes(x = congruency, y = avg)) +
  theme_bw() +
  geom_point(size = 1.5, color = "#F8766D") +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 0.5, color = "#F8766D") +
  ylim(c(0.02, 0.075)) +
  ylab("Error rate") +
  xlab("Congruency") +
  theme(text = element_text(size = 8)) +
  theme(panel.spacing = unit(1, "lines")) 
  


