# Data analysis script for Stroop Experiment 2b RT/error timbre adjective associations
# December 2018
# Zachary Wallmark

# Load libraries
set.seed(1234)

library(readr)
library(tidyverse)
library(lme4)
library(ggpubr)

# Load data
complete = readRDS(file = "exp2b.rds")

################################
## PREPROCESSING
################################
# Accuracy check: Cut Subjs with > 33% error (5 participants)
outliers = complete %>% 
  group_by(Subj) %>%
  summarise(err = 1 - mean(Accuracy)) %>%
  arrange(desc(err))
complete <- complete %>% filter(Subj != 47104568, Subj != 47545125, Subj != 47666584, Subj != 47328649,
                                Subj != 47386356)

# make outlier trimmed df: complete_trim
complete_outliers <- complete %>% filter(RT < 100 | RT > 2000)
complete_trim <- complete %>% filter(RT > 100 & RT < 2000)
nrow(complete_outliers) #51 RTs were either below 100ms or above 2000ms

# Table: Descriptive stats by Block, Modality, and Congruency
complete_trim %>% 
  filter(Accuracy == "TRUE") %>%
  group_by(Block, Congruency, Modality) %>% 
  summarise(med = median(RT), IQR = IQR(RT))

# Table, con't: Description of error
complete_trim %>% 
  group_by(Congruency) %>% 
  summarise(error = 1 - mean(Accuracy))

# Create outlier trimmed, incorrect trimmed final df: COMPLETE
COMPLETE = complete_trim %>% 
  filter(Accuracy == "TRUE")

# Visualise log-RT
ggplot(COMPLETE, aes(x = RT, fill = Congruency)) + 
  geom_density(alpha = 0.5)

################################
## ANALYSIS
################################

########### LMM model of log-RT:
COMPLETE$Congruency = relevel(COMPLETE$Congruency, ref = "incongruent")

complete_mod = lmer(log ~ Block*Congruency*Modality*MT + (1|Subj), data = COMPLETE %>% filter(Congruency != "control"))
summary(complete_mod)
Anova(complete_mod) # for Wald-chi^2

# post hoc
pairwise.t.test(COMPLETE$log, COMPLETE$Congruency, p.adjust.method = "fdr")

# model diagnostics: check effect sizes of models
r2.corr.mer <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$r.squared
}
r2.corr.p <- function(m) {
  lmfit <-  lm(model.response(model.frame(m)) ~ fitted(m))
  summary(lmfit)$coefficients
}
r2.corr.mer(complete_mod)
r2.corr.p(complete_mod)

# plot interactions (exploratory): Congruency*MT, Block*MT
interaction.plot(COMPLETE$Congruency, COMPLETE$MT, COMPLETE$RT, fun = mean)
interaction.plot(COMPLETE$Block, COMPLETE$MT, COMPLETE$log, fun = median)

######## Test-retest reliability
t1 = complete %>% filter(Trial == 1)
t2 = complete %>% filter(Trial == 2)
t1$Order2 = t2$Order
t1$log2 = t2$log
t1$seq = ifelse(t1$Order < t1$Order2, "forward", "backward")
cor1 = t1 %>% filter(seq == "forward") %>% summarise(cor = cor.test(log, log2)$estimate, df = cor.test(log, log2)$parameter, p = cor.test(log, log2)$p.value)
cor2 = t1 %>% filter(seq == "backward") %>% summarise(cor = cor.test(log2, log)$estimate, df = cor.test(log2, log)$parameter, p = cor.test(log2, log)$p.value)
# Results are average of cor1 + cor2 (cor1 = T1 first, T2 second; cor2 = T2 first, T1 second)

########### 
#Error LMM analysis
###########
complete_trim$Congruency = factor(complete_trim$Congruency, levels = c("control", "congruent", "incongruent"))
error_mod = lmer(Accuracy ~ Block*Congruency*Modality*MT + (1|Subj), 
                 family = "binomial", data = complete_trim %>% filter(Congruency != "control"))
summary(error_mod)
Anova(error_mod) # for Wald-chi^2 summary

# post hoc comparison on Congruency
complete_trim1 = complete_trim %>% filter(Congruency != "control")
pairwise.t.test(complete_trim1$Accuracy, complete_trim1$Congruency)

# model fit diagnostics
r2.corr.mer(error_mod)
r2.corr.p(error_mod)

# Interaction plotting
interaction.plot(complete_trim$Block, complete_trim$Modality, complete_trim$Accuracy, fun = mean)

########################
#Figures
########################

# Fig 3a: Graph of RT by congruency
COMPLETE$Congruency = factor(COMPLETE$Congruency, levels = c("control", "congruent", "incongruent"))
rt = COMPLETE %>% 
  filter(Congruency != "control") %>%
  group_by(Congruency) %>% 
  summarise(avg = median(RT), dev = std.error(RT)) %>% 
  ggplot(aes(x = Congruency, y = avg)) +
  theme_bw() +
  geom_point(size = 1.5, color = "#F8766D") +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 0.5, color = "#F8766D") +
  xlab("Congruency") +
  ylim(c(500, 520)) +
  theme(text = element_text(size = 8)) +
  theme(panel.spacing = unit(1, "lines")) +
  ylab("RT (ms)") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank())

# Fig 3b: Bargraph of error by congruency
complete_trim$Congruency = factor(complete_trim$Congruency, levels = c("control", "congruent", "incongruent"))
err = complete_trim %>% 
  filter(Congruency != "control") %>%
  group_by(Congruency) %>% 
  summarise(avg = 1 - mean(Accuracy), dev = std.error(Accuracy)) %>% 
  ggplot(aes(x = Congruency, y = avg)) +
  theme_bw() +
  geom_point(size = 1.5, color = "#F8766D") +
  geom_errorbar(aes(ymin = avg - dev, ymax = avg + dev), width = 0.1, size = 0.5, color = "#F8766D") +
  ylim(c(0.05, 0.075)) +
  ylab("Error rate") +
  xlab("Congruency") +
  theme(text = element_text(size = 8)) +
  theme(panel.spacing = unit(1, "lines")) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank()) 
  
# combine
ggarrange(rt, err, labels = c("A", "B"), align = "v", ncol = 2, nrow = 1)
  

  

